@@ -3,7 +3,7 @@
  */
 package org.gcube.portlets.user.td.openwidget.client;
 
-import org.gcube.portlets.user.td.gwtservice.shared.TabResource;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 
 import com.google.gwt.editor.client.Editor.Path;
 import com.sencha.gxt.core.client.ValueProvider;
